#include "Ent.h"
#include "Com.h"

Ent::Ent()
{
}

Ent::Ent(std::string id)
	: Obj(std::move(id))
{
}

Ent::Ent(Ent&& ent) noexcept
	: Obj(std::move(ent)), coms(std::move(ent.coms)), pos(ent.pos)
{
	ent.pos = {};
}

Ent::Ent(const Ent& ent)
	: Obj(ent), coms(ent.coms), pos(ent.pos)
{
}

Ent& Ent::operator=(Ent&& ent) noexcept
{
	if (this == &ent)
		return *this;

	Obj::operator=(std::move(ent));

	coms = std::move(ent.coms);
	pos = ent.pos;

	ent.pos = {};

	return *this;
}

Ent& Ent::operator=(const Ent& ent)
{
	if (this == &ent)
		return *this;

	coms = ent.coms;
	pos = ent.pos;

	return *this;
}

bool Ent::HasCom(size_t hashId)
{
	for (size_t i = 0; i < coms.size(); i++)
		if (coms[i]->GetHashId() == hashId)
			return true;

	return false;
}

bool Ent::HasCom(const std::string& id)
{
	return HasCom(Hash(id));
}

bool Ent::AddCom(Com* newCom)
{
	if (HasCom(newCom->GetHashId()))
		return false;

	coms.push_back(newCom);

	return true;
}

Com* Ent::GetCom(size_t hashId) const
{
	for (size_t i = 0; i < coms.size(); i++)
		if (coms[i]->GetHashId() == hashId)
			return coms[i];

	return nullptr;
}

Com* Ent::GetCom(const std::string& id) const
{
	return GetCom(Hash(id));
}

void Ent::SetPos(const Vec2& newPos)
{
	pos = newPos;
}

Vec2 Ent::GetPos() const
{
	return pos;
}

void Ent::Update()
{
	for (size_t i = 0; i < coms.size(); i++)
		coms[i]->Update();
}

void Ent::Render()
{
	for (size_t i = 0; i < coms.size(); i++)
		coms[i]->Render();
}
