#include "GameLoop.h"
#include "Level.h"

GameLoop::GameLoop()
	: running(false)
{
}

GameLoop::GameLoop(GameLoop&& gl) noexcept
	: lvls(std::move(gl.lvls)), running(gl.running)
{
	gl.running = false;
}

GameLoop::GameLoop(const GameLoop& gl)
	: lvls(gl.lvls), running(gl.running)
{
}

GameLoop& GameLoop::operator=(GameLoop&& gl) noexcept
{
	if (this == &gl)
		return *this;

	lvls = std::move(gl.lvls);
	running = gl.running;

	gl.running = false;

	return *this;
}

GameLoop& GameLoop::operator=(const GameLoop& gl)
{
	if (this == &gl)
		return *this;

	lvls = gl.lvls;
	running = gl.running;

	return *this;
}

bool GameLoop::HasLevel(size_t hashId) const
{
	for (size_t i = 0; i < lvls.size(); i++)
		if (lvls[i]->GetHashId() == hashId)
			return true;

	return false;
}

bool GameLoop::HasLevel(const std::string& id) const
{
	return HasLevel(Hash(id));
}

bool GameLoop::AddLevel(Level* newLvl)
{
	if (HasLevel(newLvl->GetHashId()))
		return false;

	lvls.push_back(newLvl);

	return true;
}

Level* GameLoop::GetLevel(size_t hashId) const
{
	for (size_t i = 0; i < lvls.size(); i++)
		if (lvls[i]->GetHashId() == hashId)
			return lvls[i];

	return nullptr;
}

Level* GameLoop::GetLevel(const std::string& id) const
{
	return GetLevel(Hash(id));
}

void GameLoop::Update()
{
	for (size_t i = 0; i < lvls.size(); i++)
		lvls[i]->Update();
}

void GameLoop::Render()
{
	for (size_t i = 0; i < lvls.size(); i++)
		lvls[i]->Render();
}

void GameLoop::Tick()
{
	Update();
	Render();
}

void GameLoop::Start()
{
	if (running)
		return;

	running = true;
	while (running)
		Tick();
}

void GameLoop::Stop()
{
	running = false;
}
