#include "Level.h"

Level::Level()
{
}

Level::Level(std::string id)
	: Obj(std::move(id))
{
}

Level::Level(Level&& lvl) noexcept
	: Obj(std::move(lvl)), ents(std::move(lvl.ents))
{
}

Level::Level(const Level& lvl)
	: Obj(lvl), ents(lvl.ents)
{
}

Level& Level::operator=(Level&& lvl) noexcept
{
	if (this == &lvl)
		return *this;

	Obj::operator=(std::move(lvl));

	ents = std::move(lvl.ents);

	return *this;
}

Level& Level::operator=(const Level& lvl)
{
	if (this == &lvl)
		return *this;

	Obj::operator=(lvl);

	ents = lvl.ents;

	return *this;
}

bool Level::HasEnt(size_t hashId) const
{
	for (size_t i = 0; i < ents.size(); i++)
		if (ents[i].GetHashId() == hashId)
			return true;

	return false;
}

bool Level::HasEnt(const std::string& id) const
{
	return HasEnt(Hash(id));
}

bool Level::AddEnt(Ent newEnt)
{
	if (HasEnt(newEnt.GetHashId()))
		return false;

	ents.push_back(std::move(newEnt));

	return true;
}

Ent* Level::GetEnt(size_t hashId)
{
	for (size_t i = 0; i < ents.size(); i++)
		if (ents[i].GetHashId() == hashId)
			return &ents[i];

	return nullptr;
}

Ent* Level::GetEnt(const std::string& id)
{
	return GetEnt(Hash(id));
}

void Level::Update()
{
	for (size_t i = 0; i < ents.size(); i++)
		ents[i].Update();
}

void Level::Render()
{
	for (size_t i = 0; i < ents.size(); i++)
		ents[i].Render();
}
