#include "coms/Stats.h"

Stats::Stats()
	: Com("Stats"), level(0), strength(0), dexterity(0), constitution(0), intelligence(0), wisdom(0), charisma(0),
	maxHealth(0), health(0)
{
}

Stats::Stats(uint8_t strength, uint8_t dexterity, uint8_t constitution, uint8_t intelligence, uint8_t wisdom, uint8_t charisma)
	: Com("Stats"), level(1), strength(strength), dexterity(dexterity), constitution(constitution), intelligence(intelligence),
	wisdom(wisdom), charisma(charisma)
{
}

Stats::Stats(Stats&& stats) noexcept
	: Com(std::move(stats)), level(stats.level), strength(stats.strength), dexterity(stats.dexterity),
	constitution(stats.constitution), intelligence(stats.intelligence), wisdom(stats.wisdom), charisma(stats.charisma),
	maxHealth(stats.maxHealth), health(stats.health)
{
	stats.level = 0;
	stats.strength = 0;
	stats.dexterity = 0;
	stats.constitution = 0;
	stats.intelligence = 0;
	stats.wisdom = 0;
	stats.wisdom = 0;
	stats.charisma = 0;
	stats.maxHealth = 0;
	stats.health = 0;
}

Stats::Stats(const Stats& stats)
	: Com(stats), level(stats.level), strength(stats.strength), dexterity(stats.dexterity),
	constitution(stats.constitution), intelligence(stats.intelligence), wisdom(stats.wisdom), charisma(stats.charisma),
	maxHealth(stats.maxHealth), health(stats.health)
{

}

Stats& Stats::operator=(Stats&& stats) noexcept
{
	if (this == &stats)
		return *this;

	Com::operator=(std::move(stats));

	level = stats.level;
	strength = stats.strength;
	dexterity = stats.dexterity;
	constitution = stats.constitution;
	intelligence = stats.intelligence;
	wisdom = stats.wisdom;
	charisma = stats.charisma;
	maxHealth = stats.maxHealth;
	health = stats.health;

	stats.level = 0;
	stats.strength = 0;
	stats.dexterity = 0;
	stats.constitution = 0;
	stats.intelligence = 0;
	stats.wisdom = 0;
	stats.wisdom = 0;
	stats.charisma = 0;
	stats.maxHealth = 0;
	stats.health = 0;

	return *this;
}

Stats& Stats::operator=(const Stats& stats)
{
	if (this == &stats)
		return *this;

	Com::operator=(stats);

	level = stats.level;
	strength = stats.strength;
	dexterity = stats.dexterity;
	constitution = stats.constitution;
	intelligence = stats.intelligence;
	wisdom = stats.wisdom;
	charisma = stats.charisma;
	maxHealth = stats.maxHealth;
	health = stats.health;

	return *this;
}

uint8_t Stats::GetLevel() const
{
	return level;
}

uint8_t Stats::GetStrength() const
{
	return strength;
}

uint8_t Stats::GetDexterity() const
{
	return dexterity;
}

uint8_t Stats::GetConstitution() const
{
	return constitution;
}

uint8_t Stats::GetIntelligence() const
{
	return intelligence;
}

uint8_t Stats::GetWisdom() const
{
	return wisdom;
}

uint8_t Stats::GetCharisma() const
{
	return charisma;
}

uint8_t Stats::GetMaxHealth() const
{
	return maxHealth;
}

void Stats::SetHealth(uint8_t newHealth)
{
	health = newHealth;
}

void Stats::TakeDmg(uint8_t dmg)
{
	health -= dmg;
}

void Stats::Heal(uint8_t heal)
{
	health += heal;
}

uint8_t Stats::GetHealth() const
{
	return health;
}

